@@ -106,12 +106,23 @@ _PREDEFS = (ANY, ALL, NONE)
 
 def _typeof(p: inspect.Parameter):
     """Guess parameter type, possibly with some type inference."""
-    return (
-        dict if p.kind is inspect.Parameter.VAR_KEYWORD else
-        list if p.kind is inspect.Parameter.VAR_POSITIONAL else
-        p.annotation if p.annotation is not inspect._empty else
-        type(p.default) if p.default and p.default is not inspect._empty else
-        str)
+    if p.kind is inspect.Parameter.VAR_KEYWORD:
+        return dict
+    elif p.kind is inspect.Parameter.VAR_POSITIONAL:
+        return list
+    elif p.annotation is not inspect._empty:
+        a = p.annotation
+        # NOTE Optional[?] == Union[?, None]
+        # FIXME how to recognize reliably an Optional[?]
+        if hasattr(a, "__origin__") and a.__origin__ is Union and len(a.__args__) == 2:
+            # needs 3.10: and isinstance(a.__args__[1], type(None)):
+            return a.__args__[0]
+        else:
+            return a
+    elif p.default and p.default is not inspect._empty:
+        return type(p.default)
+    else:
+        return str
 
 
 class Reference(ppp.Proxy):
